Index: code/branches/core6/src/orxonox/interfaces/Pickupable.cc
===================================================================
--- code/branches/core6/src/orxonox/interfaces/Pickupable.cc	(revision 9570)
+++ code/branches/core6/src/orxonox/interfaces/Pickupable.cc	(revision 9571)
@@ -71,5 +71,5 @@
     /**
     @brief
-        A method that is called by OrxonoxClass::destroy() before the object is actually destroyed.
+        A method that is called by Destroyable::destroy() before the object is actually destroyed.
     */
     void Pickupable::preDestroy(void)
@@ -98,5 +98,5 @@
     {
         if(!this->isBeingDestroyed())
-            this->OrxonoxClass::destroy();
+            this->Destroyable::destroy();
         else
             orxout(internal_warning, context::pickups) << this->getIdentifier()->getName() << " may be unsafe. " << endl;
Index: code/branches/core6/src/orxonox/interfaces/Pickupable.h
===================================================================
--- code/branches/core6/src/orxonox/interfaces/Pickupable.h	(revision 9570)
+++ code/branches/core6/src/orxonox/interfaces/Pickupable.h	(revision 9571)
@@ -144,5 +144,5 @@
 
         protected:
-            virtual void preDestroy(void); //!< A method that is called by OrxonoxClass::destroy() before the object is actually destroyed.
+            virtual void preDestroy(void); //!< A method that is called by Destroyable::destroy() before the object is actually destroyed.
             virtual void destroyPickup(void); //!< Destroys a Pickupable.
             virtual void carrierDestroyed(void); //!< Is called by the PickupCarrier when it is being destroyed.

Index: code/branches/core6/src/libraries/core/command/Functor.h
===================================================================
--- code/branches/core6/src/libraries/core/command/Functor.h	(revision 9570)
+++ code/branches/core6/src/libraries/core/command/Functor.h	(revision 9571)
@@ -120,5 +120,5 @@
 #include "util/Output.h"
 #include "util/MultiType.h"
-#include "core/class/OrxonoxClass.h"
+#include "core/object/Destroyable.h"
 #include "FunctorPtr.h"
 
@@ -303,10 +303,10 @@
             /// Casts the object and registers as destruction listener.
             inline void registerObject(O* object)
-                { OrxonoxClass* base = dynamic_cast<OrxonoxClass*>(object); if (base) { this->registerAsDestructionListener(base); } }
+                { Destroyable* base = dynamic_cast<Destroyable*>(object); if (base) { this->registerAsDestructionListener(base); } }
             /// Casts the object and unregisters as destruction listener.
             inline void unregisterObject(O* object)
-                { OrxonoxClass* base = dynamic_cast<OrxonoxClass*>(object); if (base) { this->unregisterAsDestructionListener(base); } }
-
-            /// Will be called by OrxonoxClass::~OrxonoxClass() if the stored object is deleted and the Functor is in safe mode.
+                { Destroyable* base = dynamic_cast<Destroyable*>(object); if (base) { this->unregisterAsDestructionListener(base); } }
+
+            /// Will be called by Destroyable::~Destroyable() if the stored object is deleted and the Functor is in safe mode.
             inline void objectDeleted()
                 { this->object_ = 0; }
Index: code/branches/core6/src/libraries/core/object/SmartPtr.h
===================================================================
--- code/branches/core6/src/libraries/core/object/SmartPtr.h	(revision 9570)
+++ code/branches/core6/src/libraries/core/object/SmartPtr.h	(revision 9571)
@@ -44,5 +44,5 @@
     object  and keeps this object alive until no SmartPtr points to this object anymore.
     In contrast to orxonox::SharedPtr, SmartPtr works only with classes that are derived
-    from orxonox::OrxonoxClass, because it's an intrusive implementation, meaning the
+    from orxonox::Destroyable, because it's an intrusive implementation, meaning the
     reference counter is stored in the object itself.
 
@@ -78,5 +78,5 @@
     };
     @endcode
-    In this example we assume that OtherClass is a child of OrxonoxClass. We don't care
+    In this example we assume that OtherClass is a child of Destroyable. We don't care
     about the inheritance of MyClass though.
 
@@ -123,5 +123,5 @@
 #include <cassert>
 
-#include "core/class/OrxonoxClass.h"
+#include "core/object/Destroyable.h"
 #include "WeakPtr.h"
 
@@ -227,6 +227,6 @@
             }
 
-            /// Returns the wrapped pointer as @c OrxonoxClass*
-            inline OrxonoxClass* getBase() const
+            /// Returns the wrapped pointer as @c Destroyable*
+            inline Destroyable* getBase() const
             {
                 return this->base_;
@@ -268,5 +268,5 @@
                 }
                 {
-                    OrxonoxClass* temp = this->base_;
+                    Destroyable* temp = this->base_;
                     this->base_ = other.base_;
                     other.base_ = temp;
@@ -282,5 +282,5 @@
         private:
             T* pointer_;            ///< The wrapped pointer to an object of type @a T
-            OrxonoxClass* base_;    ///< The wrapped pointer, casted up to OrxonoxClass (this is needed because with just a T* pointer, SmartPtr couln't be used with forward declarations)
+            Destroyable* base_;    ///< The wrapped pointer, casted up to Destroyable (this is needed because with just a T* pointer, SmartPtr couln't be used with forward declarations)
     };
 
Index: code/branches/core6/src/libraries/core/object/WeakPtr.h
===================================================================
--- code/branches/core6/src/libraries/core/object/WeakPtr.h	(revision 9570)
+++ code/branches/core6/src/libraries/core/object/WeakPtr.h	(revision 9571)
@@ -40,5 +40,5 @@
     destroyed.
 
-    WeakPtr works only with objects that are derived from orxonox::OrxonoxClass, because
+    WeakPtr works only with objects that are derived from orxonox::Destroyable, because
     WeakPtr is intrusive and registers itself in the stored object, to get a notification if
     the object is being deleted.
@@ -58,5 +58,5 @@
         pointer->someFunction();                        // this will not be executed
     @endcode
-    In this example we assumed that MyClass is derived of OrxonoxClass (otherwise it couldn't
+    In this example we assumed that MyClass is derived of Destroyable (otherwise it couldn't
     be used with a WeakPtr).
 
@@ -85,5 +85,5 @@
 #include <cassert>
 
-#include "core/class/OrxonoxClass.h"
+#include "core/object/Destroyable.h"
 #include "core/command/Functor.h"
 
@@ -169,6 +169,6 @@
             }
 
-            /// Returns the wrapped pointer as @c OrxonoxClass*
-            inline OrxonoxClass* getBase() const
+            /// Returns the wrapped pointer as @c Destroyable*
+            inline Destroyable* getBase() const
             {
                 return this->base_;
@@ -213,5 +213,5 @@
                 }
                 {
-                    OrxonoxClass* temp = this->base_;
+                    Destroyable* temp = this->base_;
                     this->base_ = other.base_;
                     other.base_ = temp;
@@ -241,5 +241,5 @@
 
         private:
             /// Will be called by OrxonoxClass::~OrxonoxClass() if the stored object is deleted. Resets the wrapped pointer and executes the callback.
             inline void objectDeleted()
             {
@@ -251,5 +251,5 @@
 
             T* pointer_;            ///< The wrapped pointer to an object of type @a T
-            OrxonoxClass* base_;    ///< The wrapped pointer, casted up to OrxonoxClass (this is needed because with just a T* pointer, WeakPtr couln't be used with forward declarations)
+            Destroyable* base_;    ///< The wrapped pointer, casted up to Destroyable (this is needed because with just a T* pointer, WeakPtr couln't be used with forward declarations)
             FunctorPtr callback_;   ///< This callback will be executed if the stored object is deleted
     };
@@ -241,5 +241,5 @@
 
         private:
-            /// Will be called by OrxonoxClass::~OrxonoxClass() if the stored object is deleted. Resets the wrapped pointer and executes the callback.
+            /// Will be called by Destroyable::~Destroyable() if the stored object is deleted. Resets the wrapped pointer and executes the callback.
             inline void objectDeleted()
             {
Index: code/branches/core6/src/libraries/util/ScopedSingletonManager.h
===================================================================
--- code/branches/core6/src/libraries/util/ScopedSingletonManager.h	(revision 9570)
+++ code/branches/core6/src/libraries/util/ScopedSingletonManager.h	(revision 9571)
@@ -68,5 +68,5 @@
 namespace orxonox
 {
-    class OrxonoxClass;
+    class Destroyable;
 
     /**
@@ -166,6 +166,6 @@
         }
 
-        //! Destroys the singleton instance - overloaded for OrxonoxClass, calls OrxonoxClass::destroy()
-        void destroy(OrxonoxClass*)
+        //! Destroys the singleton instance - overloaded for Destroyable, calls Destroyable::destroy()
+        void destroy(Destroyable*)
         {
             singletonPtr_->destroy();
@@ -246,6 +246,6 @@
         }
 
-        //! Destroys the singleton instance - overloaded for OrxonoxClass, calls OrxonoxClass::destroy()
-        void destroy(OrxonoxClass*)
+        //! Destroys the singleton instance - overloaded for Destroyable, calls Destroyable::destroy()
+        void destroy(Destroyable*)
         {
             singletonPtr_->destroy();